package com.logicbig.example;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import java.util.Arrays;
import java.util.List;

@Component
public class ExampleClient {

    @Autowired
    private EmployeeRepository repo;

    public void run() {
        List<Employee> employees = createEmployees();
        repo.saveAll(employees);

        System.out.println(" -- finding all employees --");
        Iterable<Employee> all = repo.findAll();
        all.forEach(System.out::println);

        System.out.println(" -- finding the employee count in IT dept --");
        long count = repo.countByDept("IT");
        System.out.println(count);

        System.out.println(" -- finding the employee count with salary greater or equal to 4000  --");
        count = repo.countBySalaryGreaterThanEqual(4000);
        System.out.println(count);

        System.out.println(" -- finding the employee count with name ending with 'e'  --");
        count = repo.countByNameEndingWith("e");
        System.out.println(count);

        System.out.println(" -- finding the employee count with name like '%a_a' --");
        count = repo.countByNameLike("%a_a");
        System.out.println(count);
    }

    private List<Employee> createEmployees() {
        return Arrays.asList(
                Employee.create("Diana", "Admin", 3000),
                Employee.create("Mike", "IT", 1000),
                Employee.create("Rose", "IT", 4000),
                Employee.create("Sara", "Admin", 3500),
                Employee.create("Tanaka", "IT", 3000),
                Employee.create("Charlie", "IT", 4500)
        );
    }
}